@@ -41,8 +41,11 @@
 /* Define if strptime is present AND works */
 #undef HAVE_STRPTIME
 
+/* Define to 1 if minor() macro (or function) is present */
+#undef HAVE_MINOR
+
 @BOTTOM@
 
 /* Define for backwards compatibility */
-#define ZFT_OBSOLETE
+#define CONFIG_ZFT_OBSOLETE
 
