@@ -813,9 +813,9 @@ proc ContentsCmdHandler { listWidget fd} {
 		}
 		ContentsWidgetsUpdate [expr $VolumeCount - 1]
 		update
+	    } else {
+		puts "Corrupt entry $contentsline\n"
 	    }
-	} else {
-	    puts "Corrupt entry $contentsline\n"
 	}
 	[SN UndoVolumeButton] configure -state disabled
 	fileevent $CmdPipeFD readable $oldscript
@@ -942,7 +942,7 @@ proc RunContentsCmd { listWidget {cmd "vtblc -f /dev/nrawft0"} {input ""}} {
     } else {
 	set mode RDWR
     }
-    if {[catch {open "|$cmd --print=parsable 2> /tmp/ftape-tool.[pid]" $mode} CmdPipeFD]} {
+    if {[catch {open "|$cmd --print=tagged 2> /tmp/ftape-tool.[pid]" $mode} CmdPipeFD]} {
  	foreach fileLine [split $CmdPipeFD "\n"] {
  	    $listWidget insert end $fileLine
  	}
@@ -1065,7 +1065,7 @@ proc TapeContents { {tapedev "/dev/nqft0"} FDName} {
     set outputframe [SN cmdframe]
     VFrame[SN cmdframe] [SN cmdframe]
     ClearList [SN cmdframe].frame.listbox1
-    CmdInList [SN cmdframe].frame.listbox1 "vtblc -f $tapedev --print=parsable"  Contents $FDName
+    CmdInList [SN cmdframe].frame.listbox1 "vtblc -f $tapedev --print=tagged"  Contents $FDName
 }
 
 
