@@ -76,6 +76,107 @@ unset counter
 unset tmpArgv
 
 
+# procedure to show window .top5
+proc ShowWindow.top5 {args} {# xf ignore me 7
+
+  # build widget .top5
+  if {"[info procs XFEdit]" != ""} {
+    catch "XFDestroy .top5"
+  } {
+    catch "destroy .top5"
+  }
+  toplevel .top5 
+
+  # Window manager configurations
+  wm positionfrom .top5 ""
+  wm sizefrom .top5 program
+  wm geometry .top5 212x84
+  wm maxsize .top5 212 84
+  wm minsize .top5 212 84
+  wm protocol .top5 WM_DELETE_WINDOW {XFProcError {Application windows can not be destroyed.
+Please use the "Current widget path:" to show/hide windows.}}
+  wm title .top5 {Set Partition}
+
+
+  # build widget .top5.frame7
+  frame .top5.frame7 \
+    -borderwidth {2} \
+    -height {30} \
+    -relief {raised} \
+    -width {30}
+
+  # build widget .top5.frame7.scale6
+  scale .top5.frame7.scale6 \
+    -orient {horizontal} \
+    -relief {raised} \
+    -to {1.0} -variable PartitionNumber
+
+  # build widget .top5.frame8
+  frame .top5.frame8 \
+    -borderwidth {2} \
+    -height {30} \
+    -relief {raised} \
+    -width {30}
+
+  # build widget .top5.frame8.button9
+  button .top5.frame8.button9 \
+    -command {TapeCmd $Options(NoRewindDevice) "setpart $PartitionNumber" CmdPipeFD
+DestroyWindow[SN SetPartDialog]} \
+    -padx {9} \
+    -pady {3} \
+    -text {Accept}
+
+  # build widget .top5.frame8.button10
+  button .top5.frame8.button10 \
+    -command {DestroyWindow[SN SetPartDialog]} \
+    -padx {9} \
+    -pady {3} \
+    -text {Cancel}
+
+  # pack master .top5.frame7
+  pack configure .top5.frame7.scale6 \
+    -anchor n \
+    -expand 1 \
+    -fill x
+
+  # pack master .top5.frame8
+  pack configure .top5.frame8.button9 \
+    -expand 1 \
+    -fill x \
+    -side left
+  pack configure .top5.frame8.button10 \
+    -expand 1 \
+    -fill both \
+    -side left
+
+  # pack master .top5
+  pack configure .top5.frame7 \
+    -expand 1 \
+    -fill x
+  pack configure .top5.frame8 \
+    -fill x
+
+  if {"[info procs XFEdit]" != ""} {
+    catch "XFMiscBindWidgetTree .top5"
+    after 2 "catch {XFEditSetShowWindows}"
+  }
+}
+
+proc DestroyWindow.top5 {} {# xf ignore me 7
+  if {"[info procs XFEdit]" != ""} {
+    if {"[info commands .top5]" != ""} {
+      global xfShowWindow.top5
+      set xfShowWindow.top5 0
+      XFEditSetPath .
+      after 2 "XFSaveAsProc .top5; XFEditSetShowWindows"
+    }
+  } {
+    catch "destroy .top5"
+    update
+  }
+}
+
+
 # procedure to show window ShowWindow.top1
 proc ShowWindow.top1 { args} {
 # xf ignore me 7
@@ -374,7 +475,7 @@ proc ShowWindow. {args} {# xf ignore me 7
 
   # build widget .frame0.menubutton5.m
   menu .frame0.menubutton5.m \
-    -tearoff {0}
+    -tearoff {1}
   .frame0.menubutton5.m add command \
     -command {set cmdstatus "ready"
 	if {"[info procs XFEdit]" == ""} {
@@ -406,7 +507,7 @@ CloseFD CmdPipeFD 1} \
 
   # build widget .frame0.menubutton0.m
   menu .frame0.menubutton0.m \
-    -tearoff {0}
+    -tearoff {1}
   .frame0.menubutton0.m add command \
     -command {ShowWindow.top0} \
     -label {About}
@@ -424,7 +525,7 @@ CloseFD CmdPipeFD 1} \
 
   # build widget .frame0.menubutton13.m
   menu .frame0.menubutton13.m \
-    -tearoff {0}
+    -tearoff {1}
   .frame0.menubutton13.m add command \
     -command {TapeCmd $Options(NoRewindDevice) "status" CmdPipeFD} \
     -label {Status}
@@ -434,12 +535,18 @@ CloseFD CmdPipeFD 1} \
   .frame0.menubutton13.m add command \
     -command {TapeCmd $Options(NoRewindDevice) "rewind" CmdPipeFD} \
     -label {Rewind}
+  .frame0.menubutton13.m add command \
+    -command {TapeCmd $Options(NoRewindDevice) "reten" CmdPipeFD} \
+    -label {Retension}
   .frame0.menubutton13.m add command \
     -command {TapeCmd $Options(NoRewindDevice) "rewoffl" CmdPipeFD} \
     -label {Eject}
   .frame0.menubutton13.m add command \
-    -command {TapeCmd $Options(NoRewindDevice) "reten" CmdPipeFD} \
-    -label {Retension}
+    -command {TapeCmd $Options(NoRewindDevice) "load" CmdPipeFD} \
+    -label {Load}
+  .frame0.menubutton13.m add command \
+    -command {ShowWindow[SN SetPartDialog]} \
+    -label {SetPart}
   .frame0.menubutton13.m add command \
     -command {if {[AlertBox "WARNING: FILE MARKS AND DATA MIGHT BE LOST"  "" "" "Reset" "CANCEL" "OK"] == 1} {
 	AlertBox "YOU HAVE BEEN WARNED" "" "" "Reset" "CONTINUE"
@@ -465,12 +572,12 @@ CloseFD CmdPipeFD 1} \
 
   # build widget .frame0.menubutton1.m
   menu .frame0.menubutton1.m \
-    -tearoff {0}
+    -tearoff {1}
   .frame0.menubutton1.m add command \
     -command {set newtapedev $Options(NoRewindDevice)
 set newrawdev $Options(RawNoRewindDevice)
 ShowWindow.top3} \
-    -label {Prefenrences}
+    -label {Preferences}
   .frame0.menubutton1.m add command \
     -command {SaveOptions} \
     -label {Save Options}
@@ -557,10 +664,10 @@ CloseFD CmdPipeFD 1} \
 
   # build widget .frame1.button8
   button .frame1.button8 \
-    -command {TapeCmd $Options(NoRewindDevice) "rewind" CmdPipeFD} \
+    -command {TapeCmd $Options(NoRewindDevice) "load" CmdPipeFD} \
     -padx {9} \
     -pady {3} \
-    -text {Rewind}
+    -text {Load}
 
   # build widget .frame1.button9
   button .frame1.button9 \
@@ -569,6 +676,13 @@ CloseFD CmdPipeFD 1} \
     -pady {3} \
     -text {Eject}
 
+  # build widget .frame1.button10
+  button .frame1.button10 \
+    -command {ShowWindow[SN SetPartDialog]} \
+    -padx {9} \
+    -pady {3} \
+    -text {SetPart}
+
   # build widget .frame3
   frame .frame3 \
     -borderwidth {2} \
@@ -760,10 +874,16 @@ set Options(RawRewindDevice) "/dev/rawft3"} \
   pack configure .frame1.button0 \
     -expand 1 \
     -fill both
+  pack configure .frame1.button2 \
+    -expand 1 \
+    -fill both
   pack configure .frame1.button9 \
     -expand 1 \
     -fill both
-  pack configure .frame1.button2 \
+  pack configure .frame1.button8 \
+    -expand 1 \
+    -fill both
+  pack configure .frame1.button10 \
     -expand 1 \
     -fill both
   pack configure .frame1.button1 \
@@ -1459,6 +1579,8 @@ proc UpdateTapeButtons { Button action} {
 	Retension
 	Reset
 	Erase
+	Load
+	SetPart
 	Format } {
 #	puts "$but\n$"
 	if {$action == "start"} {
@@ -2287,6 +2409,8 @@ proc InitGlobals {} {
   set {TimeString} {00:00:00}
   global {UserInfoString}
   set {UserInfoString} {Waiting for the tape drive to finish. Please have a little patience.}
+  global {PartitionNumber}
+  set {PartitionNumber} {1}
   global {VOLNOVar}
   set {VOLNOVar} {0}
   global {VolumeCount}
@@ -2442,11 +2566,15 @@ proc InitGlobals {} {
   set {symbolicName(ResetButton)} {.frame1.button1}
   set {symbolicName(RetensionButton)} {.frame1.button2}
   set {symbolicName(RewindButton)} {.frame1.button0}
+  set {symbolicName(LoadButton)} {.frame1.button8}
+  set {symbolicName(SetPartButton)} {.frame1.button10}
   set {symbolicName(SIGNATUREEntry)} {.frame8.frame6.frame1.frame14.frame44.value}
   set {symbolicName(SIGNATUREList)} {.frame8.frame.listbox2}
   set {symbolicName(SIGNATUREMenu)} {.frame8.frame6.frame1.frame14.frame44.menubutton2}
   set {symbolicName(STARTList)} {.frame8.frame.listbox5}
   set {symbolicName(STARTScale)} {.frame8.frame6.frame1.frame14.scale17}
+  set {symbolicName(SetPartDialog)} {.top5}
+  set {symbolicName(SetPartScale)} {.top5.frame7.scale6}
   set {symbolicName(SignatureFrame)} {.frame8.frame6.frame1.frame14.frame44}
   set {symbolicName(StartFormatButton)} {.frame6.frame15.frame9.button10}
   set {symbolicName(StatusButton)} {.frame1.button3}
