@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 1997 Claus-Justus Heine
+ *      Copyright (C) 1997-2000 Claus-Justus Heine
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 
  *
  * $RCSfile: ftfmt-options.c,v $
- * $Revision: 1.8 $
- * $Date: 1999/03/17 11:25:42 $
+ * $Revision: 1.9 $
+ * $Date: 2000/07/23 13:55:40 $
  *
  *      This program contains the options parsing for the user level
  *      floppy tape formatting stuff for the QIC-40/80/3010/3020
@@ -508,7 +508,8 @@ static void usage(FILE *file, int exit_val, char *message, ...)
 "                        Erase cartridge before verifying. NOTE: this is\n"
 "                        different from the erasing the FORMAT of the\n"
 "                        cartridge (see \"--omit-erase\"). HERE it simply\n"
-"                        means to fill all segments with zero bytes.\n"
+"                        means to fill all segments with zero bytes prior\n"
+"                        to verifying.\n"
 "\n"
 "      --print-header    Print the contents of the header segment in a\n"
 "                        keyword-value fashion. The bad sector map is also\n"
