@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 1997 Claus-Justus Heine
+ *      Copyright (C) 1997-2000 Claus-Justus Heine
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 
  *
  * $RCSfile: ftfmt-tapelib.c,v $
- * $Revision: 1.12 $
- * $Date: 2000/06/25 21:14:27 $
+ * $Revision: 1.15 $
+ * $Date: 2000/07/23 22:47:59 $
  *
  *      This program contains the tape manipulation functions for the
  *      user level floppy tape formatting stuff for the
@@ -56,6 +56,14 @@
 #include "ftfmt-bsm.h"
 #include "ftfmt-tapelib.h"
 
+#if !HAVE_MINOR
+# ifdef minor
+#  undef minor
+# endif
+/* glibc-2.0 seems not to include the "minor()" macro by default */
+# define minor(dev) ((int)((dev) & 0xff))
+#endif
+
 const ftape_error                 qic117_error[] = QIC117_ERRORS;
 const struct qic117_command_table qic117_cmd[]   = QIC117_COMMANDS;
 static int api_version = -1;
@@ -184,11 +192,11 @@ int tape_open(const char *name,
     struct mtget mtget;
     struct mtop  mtop = { MTNOP, 1 };
     ft_drive_status hw_status;
-    vendor_struct *vendor;
-    qic117_make_code *make;
+    const vendor_struct *vendor;
+    const qic117_make_code *make;
     format_parms *fmt_opts = &tpparms->fmt_parms;
-    static qic117_make_code make_codes[] = QIC117_MAKE_CODES;
-    static vendor_struct vendors[] = QIC117_VENDORS;
+    static const qic117_make_code make_codes[] = QIC117_MAKE_CODES;
+    static const vendor_struct vendors[] = QIC117_VENDORS;
 
     /* open the tape device
      */
@@ -646,8 +654,8 @@ int set_format_parms(const int tape_fd, const ftfmt_tpparms_t *tpparms)
 	   (fmt_opts->ft_qicstd & QIC_TAPE_WIDE ? 3 : 1));
     if (qic_simple_command(tape_fd, 0, QIC_SELECT_RATE, fmt, 1, NULL) != 0) {
 	fprintf(stderr,
-		_("Please ignore the error message printed above if in case\n"
-		  "that your cartridge can be formatted successfully!\n"));
+		_("Please ignore the error message printed above if\n"
+		  "your cartridge can be formatted successfully!\n"));
     } else {
 	/* If the tape drive doesn't support QIC_SELECT_FORMAT
 	 * (QIC_SELECT_RATE with param > 4) it doesn't support
@@ -944,6 +952,16 @@ int verify_cartridge(const int tape_fd,
 	return -1;
     }
 
+    /* This might save some space in the already existing bad sector
+     * map.  But don't do this if we have erased the bad sector map.
+     */
+    if (opt->keepbsm) {
+	for (i=tpparms->frst_data_segment;
+	     i <= tpparms->last_data_segment; i++) {
+	    put_bsm_entry(i, tune_bsm_entry(get_bsm_entry(i)));
+	}
+    }
+
     /* TODO: if this is a --verify-only pass, optionally erase the
      * cartridge by writing zero bytes to it.
      */
@@ -1098,11 +1116,6 @@ static int tune_bsm_before(void *hseg, const ftfmt_tpparms_t *tpparms)
 	    }
 	}
     }
-    /* This might save some space in the already existing bad sector map
-     */
-    for (i=tpparms->frst_data_segment; i <= tpparms->last_data_segment; i++) {
-	put_bsm_entry(i, tune_bsm_entry(get_bsm_entry(i)));
-    }
     return 0;
 }
 
