@@ -19,8 +19,8 @@
    */
 
  char ftmt_src[] = "$RCSfile: mt.c,v $";
- char ftmt_rev[] = "$Revision: 1.6 $";
- char ftmt_dat[] = "$Date: 1999/03/04 09:25:15 $";
+ char ftmt_rev[] = "$Revision: 1.8 $";
+ char ftmt_dat[] = "$Date: 2000/07/21 07:47:13 $";
 
 /* If -f is not given, the environment variable TAPE is used;
    if that is not set, a default device defined in sys/mtio.h is used.
@@ -80,9 +80,9 @@
                 Imagine erasing the header segments ...
    volinfo      Query information about the current volume
    getsize      Query tape capacity
-   ftcmd        send a raw floppy tape command. Be careful. Be superuser.
+   ftmode       Switch tape drive to raw-mode.
 
-   Claus-Justus Heine <claus@momo.math.rwth-aachen.de>
+   Claus-Justus Heine <claus@instmath.rwth-aachen.de>
  */
 
 /*
@@ -94,7 +94,7 @@
    unload
    setpart
 
-   Claus-Justus Heine <claus@momo.math.rwth-aachen.de>
+   Claus-Justus Heine <heine@instmath.rwth-aachen.de>
  */
 
 /*
@@ -112,7 +112,7 @@
 
    Changed this to "-l" and "--long-numbers".
 
-   Claus-Justus Heine <claus@momo.math.rwth-aachen.de>
+   Claus-Justus Heine <heine@instmath.rwth-aachen.de>
  */
 
 
@@ -215,6 +215,9 @@ char *opnames[] =
 #endif
 #ifdef MTIOCGETSIZE
    "getsize",
+#endif
+#ifdef MTIOCFTMODE
+   "ftmode",
 #endif
    "status",
    NULL
@@ -253,6 +256,9 @@ int operations[] =
 #endif
 #ifdef MTIOCGETSIZE
    MTIOCGETSIZE,
+#endif
+#ifdef MTIOCFTMODE
+   MTIOCFTMODE,
 #endif
    MTNOP
  };
@@ -378,6 +384,12 @@ main (argc, argv)
       if (get_capacity(tapedev, tapedesc, 0)) 
 	error (2, errno, "%s", tapedev);
       break;
+#endif
+#ifdef MTIOCFTMODE
+    case MTIOCFTMODE:
+      if (switch_ftmode(tapedev, tapedesc, count))
+	error (2, errno, "%s", tapedev);
+      break;
 #endif
     default:
     {
@@ -620,6 +632,22 @@ get_capacity(dev, desc, noise)
 }
 #endif
 
+#ifdef MTIOCFTMODE
+int
+switch_ftmode(dev, desc, on)
+     char *dev;
+     int desc;
+     int on;
+{
+  struct mtftmode mode;
+  int result;
+
+  mode.ft_rawmode = on ? 1 : 0;
+  result = rmtioctl (desc, MTIOCFTMODE, &mode);
+  return result;
+}
+#endif
+
 #ifdef MTIOCRDFTSEG
 int 
 get_segment(dev, desc, seg_no)
@@ -629,14 +657,28 @@ get_segment(dev, desc, seg_no)
 {
   struct mtftseg raw_seg;
   int result;
+# ifdef MTIOCFTMODE
+  struct mtftmode mode;
+
+  mode.ft_rawmode = 1;
+  rmtioctl (desc, MTIOCFTMODE, &mode); /* ignore possible error */
+# endif
 
   raw_seg.mt_data = (void *)xmalloc(32*1024);
   raw_seg.mt_mode = 0;
   raw_seg.mt_result = 0;
   raw_seg.mt_segno = seg_no;
 
-  if ((result = rmtioctl (desc, MTIOCRDFTSEG, &raw_seg)) >= 0) 
+  result = rmtioctl (desc, MTIOCRDFTSEG, &raw_seg);
+
+# ifdef MTIOCFTMODE
+  mode.ft_rawmode = 0;
+  rmtioctl (desc, MTIOCFTMODE, &mode); /* ignore possible error */
+# endif
+
+  if (result >= 0) 
   {
+
     if (raw_seg.mt_result >= 0 && raw_seg.mt_result <= 32*1024)
     {
       /*  print the raw data to stdout.
