@@ -19,8 +19,8 @@
 
  *
  * $RCSfile: ftvt.h,v $
- * $Revision: 1.8 $
- * $Date: 2000/07/22 18:53:01 $
+ * $Revision: 1.10 $
+ * $Date: 2001/08/12 16:34:20 $
  *
  *     This file contains the definitions for the volume table
  *     manipulation tool for the the QIC-40/80/3010/3020 floppy-tape
@@ -33,6 +33,7 @@ extern "C" {
 
 #include <linux/ftape.h>
 #include <linux/zftape.h>
+#include <linux/ftape-header-segment.h>
 
 #define FTVT_SIZE 128 /* bytes */
 
@@ -254,7 +255,7 @@ extern int ftvt_write(int tape_fd, const ftvt *volumes, u_int8_t *buffer,
 extern void ftvt_print(const ftvt *volumes, int maxnum);
 extern void ftvt_print_one(const ftvt *volume);
 extern void ftvt_print_one_tagged(const ftvt *volume);
-extern int ftvt_parse_tagged(ftvt *volumes);
+extern int ftvt_parse_tagged(ftvt *volumes, int fmt_code);
 extern int ftvt_add_volume(ftvt *volumes, int num_volumes);
 extern char *ftvt_decode_date(u_int32_t timestamp);
 extern int ftvt_set_date(ftvt *volumes, int maxnum,
@@ -275,7 +276,7 @@ void      ftvt_print_bad_sector_map(int verbose);
 }
 #endif
 
-#endif _FTVT_H_
+#endif /* _FTVT_H_ */
 
 /*
  * Local variables:
