@@ -22,8 +22,8 @@
  */
 
 char src[] = "$RCSfile: vtblc.c,v $";
-char rev[] = "$Revision: 1.15 $";
-char dat[] = "$Date: 2000/07/21 07:48:09 $";
+char rev[] = "$Revision: 1.16 $";
+char dat[] = "$Date: 2001/08/11 00:16:33 $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -265,7 +265,7 @@ int main(int argc, char *argv[])
 		exit(1);
 	}
 	if (taggedinput) { /* implies modify or append */
-		if ((num_volumes = ftvt_parse_tagged(volumes)) == -1) {
+		if ((num_volumes = ftvt_parse_tagged(volumes, fmt_code)) == -1) {
 			(void)ftvt_close(tapefd);
 			exit(1);
 		}
